/**
 * Copyright (c) 2005-2012 Fossil E-Commerce, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package javax.jbi.management;

/**
 * LifeCycleMBean is a base interface that defines standard life cycle controls
 * for JBI Framework services and JBI Components (bindings and engines).
 * 
 * @author JSR208 Expert Group
 */
public interface LifeCycleMBean {

	/**
     * Value returned by {@link LifeCycleMBean#getCurrentState()} for a shutdown
     * component.
     */
	public static final java.lang.String SHUTDOWN = "Shutdown";

	/**
     * Value returned by {@link LifeCycleMBean#getCurrentState()} for a started
     * component.
     */
	public static final java.lang.String STARTED = "Started";

	/**
     * Value returned by {@link LifeCycleMBean#getCurrentState()} for a stopped
     * component.
     */
	public static final java.lang.String STOPPED = "Stopped";

	/**
     * Value returned by {@link LifeCycleMBean#getCurrentState()} for a
     * component in an unknown state.
     */
	public static final java.lang.String UNKNOWN = "Unknown";

	/**
	 * Get the current state of this managed component.
	 * 
	 * @return the current state of this managed component (must be one of the
	 *         string constants defined by this interface)
	 */
	public java.lang.String getCurrentState();

	/**
     * Shut down the item. This releases resources, returning the item to an
     * unitialized state.
     * 
     * @throws javax.jbi.JBIException
     *             if the item fails to shut down
     */
	public void shutDown() throws javax.jbi.JBIException;

	/**
	 * Start the item.
	 * 
	 * @throws javax.jbi.JBIException
	 *             if the item fails to start
	 */
	public void start() throws javax.jbi.JBIException;

	/**
	 * Stop the item. This suspends current messaging activities.
	 * 
	 * @throws javax.jbi.JBIException
	 *             if the item fails to stop
	 */
	public void stop() throws javax.jbi.JBIException;
}
