/**
 * Copyright (c) 2005-2012 Fossil E-Commerce, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package javax.jbi.messaging;


/**
 * Typesafe enumeration containing status values for a message exchange.
 * 
 * @author JSR208 Expert Group
 */
public final class ExchangeStatus {

    /**
     * Indicates that an ME has not been processed to completion.
     */
    public static final javax.jbi.messaging.ExchangeStatus ACTIVE =
        new javax.jbi.messaging.ExchangeStatus("Active");

    /**
     * Indicates that an ME has been processed to completion.
     */
    public static final javax.jbi.messaging.ExchangeStatus DONE =
        new javax.jbi.messaging.ExchangeStatus("Done");

    /**
     * Indicates that an ME has terminated abnormally within the JBI
     * environment.
     */
    public static final javax.jbi.messaging.ExchangeStatus ERROR =
        new javax.jbi.messaging.ExchangeStatus("Error");

    /**
     * Internal variable to hold enumeration id.
     */
    private java.lang.String status;

    /**
     * Private constructor for type safe enumeration creation.
     */
    private ExchangeStatus(java.lang.String aStatus) {
        this.status = aStatus;
    }

    /**
     * Returns true if this ExchangeStatus has the same type and value as the
     * given object.
     * 
     * @param obj
     *            value to be compared for equality
     * @return <code>true</code> if this object is equal to the given object
     *         in type and value
     */
    /*public boolean equals(java.lang.Object obj) {
        boolean equal = false;

        if (obj instanceof ExchangeStatus) {
            ExchangeStatus es = (ExchangeStatus) obj;
            equal = this.status.equals(es.status);
        }
        return (equal);
    }*/

    /**
     * @return Returns hash code value for this object.
     */
    public int hashCode() {
        return toString().hashCode();
    }

    /**
     * Returns string value of enumerated type.
     * 
     * @return String representation of status value; must be non-null and
     *         non-empty
     */
    public java.lang.String toString() {
        return this.status;
    }

    /**
     * Returns instance of ExchangeStatus that corresponds to given string.
     * 
     * @param status
     *            String representation of status value
     * @return ExchangeStatus corresponding to the given string value; must be
     *         non-null
     * @throws java.lang.IllegalArgumentException
     *             if string can't be translated (null or non-status value)
     */
    public static javax.jbi.messaging.ExchangeStatus valueOf(
            java.lang.String status) {

    	if (status.equals(ACTIVE.toString())) {
    		return ACTIVE;
    	} else if (status.equals(DONE.toString())) {
    		return DONE;
    	} else if (status.equals(ERROR.toString())) {
    		return ERROR;
    	} else {
            throw new IllegalArgumentException("Unknown status: " + status);
    	}
    }

}
