/**
 * Copyright (c) 2005-2012 Fossil E-Commerce, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package javax.jbi.messaging;

/**
 * Supports operations used to process an In Optional Out MEP to completion.
 *
 * @author JSR208 Expert Group
 */
public interface InOptionalOut extends MessageExchange{
	
	/**
     * Retrieves the <i>in</i> message reference from this exchange.
     * 
     * @return in message; may be <code>null</code>
     * @throws java.lang.IllegalStateException
     *             if the component is not the owner of this message exchange
     */
	public javax.jbi.messaging.NormalizedMessage getInMessage();
	
	/**
     * Retrieves the <i>out</i> message reference from this exchange.
     * 
     * @return out message; may be <code>null</code>
     * @throws java.lang.IllegalStateException
     *             if the component is not the owner of this message exchange
     */
	public javax.jbi.messaging.NormalizedMessage getOutMessage();
	
	/**
     * Specifies the <i>in</i> message reference for this exchange.
     * 
     * @param msg
     *            in message; must be non-null
     * @throws MessagingException
     *             unable to set in message
     * @throws java.lang.IllegalStateException
     *             if the component is not the owner of this message exchange
     */
    public void setInMessage(javax.jbi.messaging.NormalizedMessage msg)
            throws MessagingException;
	
	/**
     * Specifies the <i>out</i> message reference for this exchange.
     * 
     * @param msg
     *            out message; must be non-null
     * @throws MessagingException
     *             unable to set out message
     * @throws java.lang.IllegalStateException
     *             if the component is not the owner of this message exchange
     */
    public void setOutMessage(javax.jbi.messaging.NormalizedMessage msg)
            throws MessagingException;
}
