/**
 * Copyright (c) 2005-2012 Fossil E-Commerce, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package javax.jbi.servicedesc;

/**
 * Reference to an endpoint, used to refer an endpoint as well as query
 * information about the endpoint.
 * <p>
 * An endpoint is an addressable entity in the JBI system, used for accessing
 * the provider of a specific service.
 * <p>
 * This interface is implemented by both the JBI implementation and JBI
 * components, in the following use cases:
 * <ul>
 *   <li><b>Activated endpoints</b>: created by JBI implementation.
 *   <li><b>Internal endpoints from endpoint resolution</b>: created by the
 *   component implementation.
 *   <li><b>Registered external endpoints</b>: created by the component
 *   implementation.
 * </ul>
 * <p>
 * See the JBI Specification for details on requirements imposed on components
 * in the latter two use cases.
 * 
 * @author JSR208 Expert Group
 */
public interface ServiceEndpoint {

	/**
	 * Get a reference to this endpoint, using an endpoint reference vocabulary
     * that is known to the provider.
     * 
     * @param operationName
     *            the name of the operation to be performed by a consumer of the
     *            generated EPR; <code>null</**
     * @return endpoint reference as an XML fragment; <code>null</code> if the
     *         provider does not support such references
     */
	public org.w3c.dom.DocumentFragment getAsReference(
			javax.xml.namespace.QName operationName);

	/**
     * Returns the endpoint name of this reference.
     * 
     * @return endpoint name; must be non-null and non-empty
     */
	public java.lang.String getEndpointName();

	/**
     * Get the qualified names of all the interfaces implemented by this service
     * endpoint.
     * 
     * @return array of all interfaces implemented by this service endpoint;
     *         must be non-null and non-empty
     */
	public javax.xml.namespace.QName[] getInterfaces();

	/**
     * Returns the service name of this reference.
     * 
     * @return qualified service name; must be non-null
     */
	public javax.xml.namespace.QName getServiceName();
}
