/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package javax.jbi.component;

import static org.mockito.Mockito.mock;

import java.lang.reflect.Method;

import javax.jbi.ApiChecker;
import javax.jbi.JBIException;
import javax.management.ObjectName;

import org.junit.Test;

/**
 * @author Olivier Fabre - EBM WebSourcing
 */
public class BootstrapTest extends ApiChecker {

    private Bootstrap mockBootstrap = mock(Bootstrap.class);

    private InstallationContext installContextMock = mock(InstallationContext.class);

    @Test
    public void testcleanUp() throws JBIException {
        mockBootstrap.cleanUp();
    }

    @Test
    public void testcleanUpThrowsJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { JBIException.class };

        Method method = getTestedClassMethod("cleanUp");

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testGetExtensionMBeanName() {
        @SuppressWarnings("unused")
        ObjectName objectName = mockBootstrap.getExtensionMBeanName();
    }

    @Test
    public void testInit() throws JBIException {
        mockBootstrap.init(installContextMock);
    }

    @Test
    public void testInitThrowsJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { JBIException.class };

        Method method = getTestedClassMethod("init", InstallationContext.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testOnInstall() throws JBIException {
        mockBootstrap.onInstall();
    }

    @Test
    public void testOnInstallThrowsJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { JBIException.class };

        Method method = getTestedClassMethod("onInstall");

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testOnUninstall() throws JBIException {
        mockBootstrap.onUninstall();
    }

    @Test
    public void testOnUninstallThrowsJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { JBIException.class };

        Method method = getTestedClassMethod("onUninstall");

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Override
    protected Class<?> getTestedApiClass() {
        return Bootstrap.class;
    }

}
