/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package javax.jbi.component;

import static org.mockito.Mockito.mock;

import java.lang.reflect.Method;
import java.util.MissingResourceException;
import java.util.logging.Logger;

import javax.jbi.ApiChecker;
import javax.jbi.JBIException;
import javax.jbi.management.MBeanNames;
import javax.jbi.messaging.DeliveryChannel;
import javax.jbi.messaging.MessagingException;
import javax.jbi.servicedesc.ServiceEndpoint;
import javax.management.MBeanServer;
import javax.naming.InitialContext;
import javax.xml.namespace.QName;

import org.junit.Test;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentFragment;

/**
 * @author Olivier Fabre - EBM WebSourcing
 */
public class ComponentContextTest extends ApiChecker {

    private ComponentContext mockComponentContext = mock(ComponentContext.class);

    private DocumentFragment mockDocumentFragment = mock(DocumentFragment.class);

    private ServiceEndpoint mockServiceEndpoint = mock(ServiceEndpoint.class);

    @Test
    public void testActivateEndpoint() throws JBIException {
        @SuppressWarnings("unused")
        ServiceEndpoint serviceEndpoint = mockComponentContext.activateEndpoint(new QName("foo"),
                "bar");
    }

    @Test
    public void testActivateEndpointThrowsJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { JBIException.class };

        Method method = getTestedClassMethod("activateEndpoint", QName.class, String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testDeactivateEndpoint() throws JBIException {
        mockComponentContext.deactivateEndpoint(mockServiceEndpoint);
    }

    @Test
    public void testDeactivateEndpointThrowsJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { JBIException.class };

        Method method = getTestedClassMethod("deactivateEndpoint", ServiceEndpoint.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testDeregisterExternalEndpoint() throws JBIException {
        mockComponentContext.deregisterExternalEndpoint(mockServiceEndpoint);
    }

    @Test
    public void testDeregisterExternalEndpointThrowsJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { JBIException.class };

        Method method = getTestedClassMethod("deregisterExternalEndpoint", ServiceEndpoint.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testGetComponentName() {
        @SuppressWarnings("unused")
        String componentName = mockComponentContext.getComponentName();
    }

    @Test
    public void testGetDeliveryChannel() throws MessagingException {
        @SuppressWarnings("unused")
        DeliveryChannel deliveryChannel = mockComponentContext.getDeliveryChannel();
    }

    @Test
    public void testGetDeliveryChannelThrowsMessagingException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

        Method method = getTestedClassMethod("getDeliveryChannel");

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testGetEndpoint() {
        @SuppressWarnings("unused")
        ServiceEndpoint serviceEndpoint = mockComponentContext.getEndpoint(new QName("bar"), "foo");
    }

    @Test
    public void testGetEndpointDescriptor() throws JBIException {
        @SuppressWarnings("unused")
        Document document = mockComponentContext.getEndpointDescriptor(mockServiceEndpoint);
    }

    @Test
    public void testGetEndpointDescriptorThrowsJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { JBIException.class };

        Method method = getTestedClassMethod("getEndpointDescriptor", ServiceEndpoint.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testGetEndpoints() {
        @SuppressWarnings("unused")
        ServiceEndpoint[] serviceEndpoints = mockComponentContext.getEndpoints(new QName("bar"));
    }

    @Test
    public void testGetEndpointsForService() {
        @SuppressWarnings("unused")
        ServiceEndpoint[] serviceEndpoints = mockComponentContext.getEndpointsForService(new QName(
                "bar"));
    }

    @Test
    public void testGetExternalEndpoints() {
        @SuppressWarnings("unused")
        ServiceEndpoint[] serviceEndpoints = mockComponentContext.getExternalEndpoints(new QName(
                "bar"));
    }

    @Test
    public void testGetExternalEndpointsForService() {
        @SuppressWarnings("unused")
        ServiceEndpoint[] serviceEndpoints = mockComponentContext
                .getExternalEndpointsForService(new QName("bar"));
    }

    @Test
    public void testGetInstallRoot() {
        @SuppressWarnings("unused")
        String installRoot = mockComponentContext.getInstallRoot();
    }

    @Test
    public void testGetLogger() throws MissingResourceException, JBIException {
        @SuppressWarnings("unused")
        Logger logger = mockComponentContext.getLogger("suffix", "resourceBundleName");
    }

    @Test
    public void testGetLoggerThrowsMissingRessourceExceptionAndJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MissingResourceException.class,
                JBIException.class };

        Method method = getTestedClassMethod("getLogger", String.class, String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testGetMBeanNames() {
        @SuppressWarnings("unused")
        MBeanNames mBeanNames = mockComponentContext.getMBeanNames();
    }

    @Test
    public void testGetMBeanServer() {
        @SuppressWarnings("unused")
        MBeanServer mBeanServer = mockComponentContext.getMBeanServer();
    }

    @Test
    public void testGetNamingContext() {
        @SuppressWarnings("unused")
        InitialContext initialContext = mockComponentContext.getNamingContext();
    }

    @Test
    public void testGetTransactionManager() {
        @SuppressWarnings("unused")
        Object object = mockComponentContext.getTransactionManager();
    }

    @Test
    public void testGetWorkspaceRoot() {
        @SuppressWarnings("unused")
        String workspaceRoot = mockComponentContext.getWorkspaceRoot();
    }

    @Test
    public void testRegisterExternalEndpoint() throws JBIException {
        mockComponentContext.registerExternalEndpoint(mockServiceEndpoint);
    }

    @Test
    public void testRegisterExternalEndpointThrowsJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { JBIException.class };

        Method method = getTestedClassMethod("registerExternalEndpoint", ServiceEndpoint.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testResolveEndpointReference() {
        @SuppressWarnings("unused")
        ServiceEndpoint endpoint = mockComponentContext
                .resolveEndpointReference(mockDocumentFragment);
    }

    @Override
    protected Class<?> getTestedApiClass() {

        return ComponentContext.class;
    }

}
