/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package javax.jbi.component;

import java.lang.reflect.Method;

import javax.jbi.ApiChecker;
import javax.jbi.JBIException;
import javax.management.ObjectName;

import org.junit.Test;
import org.mockito.Mockito;

/**
 * @author Olivier Fabre - EBM WebSourcing
 */
public class ComponentLifeCycleTest extends ApiChecker {

    ComponentLifeCycle mockComponentLifeCycle = Mockito.mock(ComponentLifeCycle.class);

    ComponentContext mockComponentContext = Mockito.mock(ComponentContext.class);

    @Test
 	public void testGetExtensionMBeanName() {
        @SuppressWarnings("unused")
        ObjectName objectName = mockComponentLifeCycle.getExtensionMBeanName();
    }

    @Test
 	public void testInit() throws JBIException {
        mockComponentLifeCycle.init(mockComponentContext);
    }

    @Test
 	public void testInitThrowsJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { JBIException.class };

        Method method = getTestedClassMethod("init", ComponentContext.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testShutDown() throws JBIException {
        mockComponentLifeCycle.shutDown();
    }

    @Test
 	public void testShutDownThrowsJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { JBIException.class };

        Method method = getTestedClassMethod("shutDown");

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testStart() throws JBIException {
        mockComponentLifeCycle.start();
    }

    @Test
 	public void testStartThrowsJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { JBIException.class };

        Method method = getTestedClassMethod("start");

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testStop() throws JBIException {
        mockComponentLifeCycle.stop();
    }

    @Test
 	public void testStopThrowsJBIException() {
        Class<?>[] expectedExceptions = new Class<?>[] { JBIException.class };

        Method method = getTestedClassMethod("stop");

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Override
    protected Class<?> getTestedApiClass() {

        return ComponentLifeCycle.class;
    }

}
