/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package javax.jbi.component;

import java.lang.reflect.Method;

import javax.jbi.ApiChecker;
import javax.jbi.management.DeploymentException;

import org.junit.Test;
import org.mockito.Mockito;

/**
 * @author Olivier Fabre - EBM WebSourcing
 */
public class ServiceUnitManagerTest extends ApiChecker {

    private ServiceUnitManager mockServiceUnitManager = Mockito.mock(ServiceUnitManager.class);

    @Test
    public void testDeploy() throws DeploymentException {
        @SuppressWarnings("unused")
        String string = mockServiceUnitManager.deploy("foo", "bar");
    }

    @Test
    public void testDeployThrowsDeploymentException() {
        Class<?>[] expectedExceptions = new Class<?>[] { DeploymentException.class };

        Method method = getTestedClassMethod("deploy", String.class, String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testInit() throws DeploymentException {
        mockServiceUnitManager.init("", "");
    }

    @Test
    public void testInitThrowsDeploymentException() {
        Class<?>[] expectedExceptions = new Class<?>[] { DeploymentException.class };

        Method method = getTestedClassMethod("init", String.class, String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testShutDown() throws DeploymentException {
        mockServiceUnitManager.shutDown("");
    }

    @Test
    public void testShutDownThrowsDeploymentException() {
        Class<?>[] expectedExceptions = new Class<?>[] { DeploymentException.class };

        Method method = getTestedClassMethod("shutDown", String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testStart() throws DeploymentException {
        mockServiceUnitManager.start("");
    }

    @Test
    public void testStartThrowsDeploymentException() {
        Class<?>[] expectedExceptions = new Class<?>[] { DeploymentException.class };

        Method method = getTestedClassMethod("start", String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testStop() throws DeploymentException {
        mockServiceUnitManager.stop("");
    }

    @Test
    public void testStopThrowsDeploymentException() {
        Class<?>[] expectedExceptions = new Class<?>[] { DeploymentException.class };

        Method method = getTestedClassMethod("stop", String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testUndeploy() throws DeploymentException {
        @SuppressWarnings("unused")
        String string = mockServiceUnitManager.undeploy("", "");
    }

    @Test
    public void testUndeployThrowsDeploymentException() {
        Class<?>[] expectedExceptions = new Class<?>[] { DeploymentException.class };

        Method method = getTestedClassMethod("undeploy", String.class, String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Override
    protected Class<?> getTestedApiClass() {
        return ServiceUnitManager.class;
    }

}
