/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package javax.jbi.management;

import java.lang.reflect.Method;

import javax.jbi.ApiChecker;

import org.junit.Test;
import org.mockito.Mockito;

/**
 * @author Olivier Fabre - EBM WebSourcing
 */
public class DeploymentServiceMBeanTest extends ApiChecker {

    DeploymentServiceMBean mockDeploymentServiceMBean = Mockito.mock(DeploymentServiceMBean.class);

    @Test
 	public void testCanDeployToComponent() {
        @SuppressWarnings("unused")
        boolean b = mockDeploymentServiceMBean.canDeployToComponent("");
    }

    @Test
 	public void testDeploy() throws Exception {
        @SuppressWarnings("unused")
        String string = mockDeploymentServiceMBean.deploy("");
    }

    @Test
 	public void testGetExtensionMBeanNameThrowsException() {
        Class<?>[] expectedExceptions = new Class<?>[] { Exception.class };

        Method method = getTestedClassMethod("deploy", String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testGetComponentsForDeployedServiceAssembly() throws Exception {
        @SuppressWarnings("unused")
        String[] strings = mockDeploymentServiceMBean.getComponentsForDeployedServiceAssembly("");
    }

    @Test
 	public void testGetComponentsForDeployedServiceAssemblyThrowsException() {
        Class<?>[] expectedExceptions = new Class<?>[] { Exception.class };

        Method method = getTestedClassMethod("getComponentsForDeployedServiceAssembly",
                String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testGetDeployedServiceAssemblies() throws Exception {
        @SuppressWarnings("unused")
        String[] strings = mockDeploymentServiceMBean.getDeployedServiceAssemblies();
    }

    @Test
 	public void testGetDeployedServiceAssembliesThrowsException() {
        Class<?>[] expectedExceptions = new Class<?>[] { Exception.class };

        Method method = getTestedClassMethod("getDeployedServiceAssemblies");

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testGetDeployedServiceAssembliesForComponent() throws Exception {
        @SuppressWarnings("unused")
        String[] strings = mockDeploymentServiceMBean.getDeployedServiceAssembliesForComponent("");
    }

    @Test
 	public void testGetDeployedServiceAssembliesForComponentThrowsException() {
        Class<?>[] expectedExceptions = new Class<?>[] { Exception.class };

        Method method = getTestedClassMethod("getDeployedServiceAssembliesForComponent",
                String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testGetDeployedServiceUnitList() throws Exception {
        @SuppressWarnings("unused")
        String[] strings = mockDeploymentServiceMBean.getDeployedServiceUnitList("");
    }

    @Test
 	public void testGetDeployedServiceUnitListThrowsException() {
        Class<?>[] expectedExceptions = new Class<?>[] { Exception.class };

        Method method = getTestedClassMethod("getDeployedServiceUnitList", String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testGetServiceAssemblyDescriptor() throws Exception {
        @SuppressWarnings("unused")
        String string = mockDeploymentServiceMBean.getServiceAssemblyDescriptor("");
    }

    @Test
 	public void testGetServiceAssemblyDescriptorThrowsException() {
        Class<?>[] expectedExceptions = new Class<?>[] { Exception.class };

        Method method = getTestedClassMethod("getServiceAssemblyDescriptor", String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testGetState() throws Exception {
        @SuppressWarnings("unused")
        String string = mockDeploymentServiceMBean.getState("");
    }

    @Test
 	public void testGetStateThrowsException() {
        Class<?>[] expectedExceptions = new Class<?>[] { Exception.class };

        Method method = getTestedClassMethod("getState", String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testIsDeployedServiceUnit() throws Exception {
        @SuppressWarnings("unused")
        boolean b = mockDeploymentServiceMBean.isDeployedServiceUnit("", "");
    }

    @Test
 	public void testIsDeployedServiceUnitThrowsException() {
        Class<?>[] expectedExceptions = new Class<?>[] { Exception.class };

        Method method = getTestedClassMethod("isDeployedServiceUnit", String.class, String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testShutDown() throws Exception {
        @SuppressWarnings("unused")
        String string = mockDeploymentServiceMBean.shutDown("");
    }

    @Test
 	public void testShutDownThrowsException() {
        Class<?>[] expectedExceptions = new Class<?>[] { Exception.class };

        Method method = getTestedClassMethod("shutDown", String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testStart() throws Exception {
        @SuppressWarnings("unused")
        String string = mockDeploymentServiceMBean.start("");
    }

    @Test
 	public void testStartThrowsException() {
        Class<?>[] expectedExceptions = new Class<?>[] { Exception.class };

        Method method = getTestedClassMethod("start", String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testStop() throws Exception {
        @SuppressWarnings("unused")
        String string = mockDeploymentServiceMBean.stop("");
    }

    @Test
 	public void testStopThrowsException() {
        Class<?>[] expectedExceptions = new Class<?>[] { Exception.class };

        Method method = getTestedClassMethod("stop", String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testUndeploy() throws Exception {
        @SuppressWarnings("unused")
        String string = mockDeploymentServiceMBean.undeploy("");
    }

    @Test
 	public void testUndeployThrowsException() {
        Class<?>[] expectedExceptions = new Class<?>[] { Exception.class };

        Method method = getTestedClassMethod("undeploy", String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Override
    protected Class<?> getTestedApiClass() {
        return DeploymentServiceMBean.class;
    }

}
