/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package javax.jbi.messaging;

import java.lang.reflect.Method;
import java.net.URI;
import java.net.URISyntaxException;

import javax.jbi.ApiChecker;
import javax.xml.namespace.QName;

import org.junit.Test;
import org.mockito.Mockito;

/**
 * @author Olivier Fabre - EBM WebSourcing
 */
public class MessageExchangeFactoryTest extends ApiChecker {

	MessageExchangeFactory mockMessageExchangeFactory = Mockito
			.mock(MessageExchangeFactory.class);

	@Test
 	public void testCreateExchange() throws MessagingException {
		@SuppressWarnings("unused")
		MessageExchange messageExchange = mockMessageExchangeFactory
				.createExchange(new QName("foo"), new QName("bar"));
	}

	@Test
 	public void testCreateExchangeThrowsMessagingException() {
		Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

		Method method = getTestedClassMethod("createExchange", QName.class,
				QName.class);

		checkMethodThrowsExpectedExceptions(method, expectedExceptions);
	}

	@Test
 	public void testCreateExchangeFromURI() throws MessagingException,
			URISyntaxException {
		@SuppressWarnings("unused")
		MessageExchange messageExchange = mockMessageExchangeFactory
				.createExchange(new URI("http://foo.com"));
	}

	@Test
 	public void testCreateExchangeFromURIThrowsMessagingException() {
		Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

		Method method = getTestedClassMethod("createExchange", URI.class);

		checkMethodThrowsExpectedExceptions(method, expectedExceptions);
	}

	@Test
 	public void testCreateInOnlyExchange() throws MessagingException {
		@SuppressWarnings("unused")
		InOnly inOnly = mockMessageExchangeFactory.createInOnlyExchange();
	}

	@Test
 	public void testCreateInOnlyExchangeThrowsMessagingException() {
		Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

		Method method = getTestedClassMethod("createInOnlyExchange");

		checkMethodThrowsExpectedExceptions(method, expectedExceptions);
	}

	@Test
 	public void testCreateInOptionalOutExchange() throws MessagingException {
		@SuppressWarnings("unused")
		InOptionalOut inOptionalOut = mockMessageExchangeFactory
				.createInOptionalOutExchange();
	}

	@Test
 	public void testCreateInOptionalOutExchangeThrowsMessagingException() {
		Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

		Method method = getTestedClassMethod("createInOptionalOutExchange");

		checkMethodThrowsExpectedExceptions(method, expectedExceptions);
	}

	@Test
 	public void testCreateInOutExchange() throws MessagingException {
		@SuppressWarnings("unused")
		InOut inOut = mockMessageExchangeFactory.createInOutExchange();
	}

	@Test
 	public void testCreateInOutExchangeThrowsMessagingException() {
		Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

		Method method = getTestedClassMethod("createInOutExchange");

		checkMethodThrowsExpectedExceptions(method, expectedExceptions);
	}

	@Test
 	public void testCreateRobustInOnlyExchange() throws MessagingException {
		@SuppressWarnings("unused")
		RobustInOnly robustInOnly = mockMessageExchangeFactory
				.createRobustInOnlyExchange();
	}

	@Test
 	public void testCreateRobustInOnlyExchangeThrowsMessagingException() {
		Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

		Method method = getTestedClassMethod("createRobustInOnlyExchange");

		checkMethodThrowsExpectedExceptions(method, expectedExceptions);
	}

	@Override
	protected Class<?> getTestedApiClass() {
		return MessageExchangeFactory.class;
	}

}
