/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package javax.jbi.messaging;

import java.lang.reflect.Method;
import java.net.URI;
import java.util.Set;

import javax.jbi.ApiChecker;
import javax.jbi.messaging.MessageExchange.Role;
import javax.jbi.servicedesc.ServiceEndpoint;
import javax.xml.namespace.QName;

import org.junit.Test;
import org.mockito.Mockito;

/**
 * @author Olivier Fabre - EBM WebSourcing
 */
public class MessageExchangeTest extends ApiChecker {

    MessageExchange messageExchange = Mockito.mock(MessageExchange.class);

    @Test
 	public void testCreateFault() throws MessagingException {
        @SuppressWarnings("unused")
        Fault fault = messageExchange.createFault();
    }

    @Test
 	public void testCreateFaultThrowsMessagingException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

        Method method = getTestedClassMethod("createFault");

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testCreateMessage() throws MessagingException {
        @SuppressWarnings("unused")
        NormalizedMessage normalizedMessage = messageExchange.createMessage();
    }

    @Test
 	public void testCreateMessageThrowsMessagingException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

        Method method = getTestedClassMethod("createMessage");

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testgetEndpoint() {
        @SuppressWarnings("unused")
        ServiceEndpoint endpoint = messageExchange.getEndpoint();
    }

    @Test
 	public void testGetError() {
        @SuppressWarnings("unused")
        Exception exception = messageExchange.getError();
    }

    @Test
 	public void testGetExchangeId() {
        @SuppressWarnings("unused")
        String string = messageExchange.getExchangeId();
    }

    @Test
 	public void testGetFlowAttributes() {
        @SuppressWarnings("unused")
        Object flowAttributes = messageExchange.getFlowAttributes();
    }
    
    @Test
 	public void testGetFault() {
        @SuppressWarnings("unused")
        Fault fault = messageExchange.getFault();
    }

    @Test
 	public void testGetInterfaceName() {
        @SuppressWarnings("unused")
        QName qName = messageExchange.getInterfaceName();
    }

    @Test
 	public void testGetMessage() {
        @SuppressWarnings("unused")
        NormalizedMessage normalizedMessage = messageExchange.getMessage("foo");
    }

    @Test
 	public void testGetOperation() {
        @SuppressWarnings("unused")
        QName qName = messageExchange.getOperation();
    }

    @Test
 	public void testGetPattern() {
        @SuppressWarnings("unused")
        URI uri = messageExchange.getPattern();
    }

    @Test
 	public void testGetProperty() {
        @SuppressWarnings("unused")
        Object object = messageExchange.getProperty("");
    }

    @Test
 	public void testGetPropertyNames() {
        @SuppressWarnings({ "unused", "rawtypes" })
        Set set = messageExchange.getPropertyNames();
    }

    @Test
 	public void testGetRole() {
        @SuppressWarnings("unused")
        Role role = messageExchange.getRole();
    }

    @Test
 	public void testGetService() {
        @SuppressWarnings("unused")
        QName qName = messageExchange.getService();
    }

    @Test
 	public void testGetStatus() {
        @SuppressWarnings("unused")
        ExchangeStatus exchangeStatus = messageExchange.getStatus();
    }

    @Test
 	public void testIsTransacted() {
        @SuppressWarnings("unused")
        boolean b = messageExchange.isTransacted();
    }

    @Test
 	public void testSetEndpoint() {
        messageExchange.setEndpoint(Mockito.mock(ServiceEndpoint.class));
    }

    @Test
 	public void testSetError() {
        messageExchange.setError(new Exception());
    }

    @Test
 	public void testSetFault() throws MessagingException {
        messageExchange.setFault(Mockito.mock(Fault.class));
    }

    @Test
 	public void testSetFaultThrowsMessagingException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

        Method method = getTestedClassMethod("setFault", Fault.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testSetInterfaceName() {
        messageExchange.setInterfaceName(new QName("foo"));
    }

    @Test
 	public void testSetMessage() throws MessagingException {
        messageExchange.setMessage(Mockito.mock(NormalizedMessage.class), "foo");
    }

    @Test
 	public void testSetMessageThrowsMessagingException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

        Method method = getTestedClassMethod("setMessage", NormalizedMessage.class, String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
 	public void testSetOperation() {
        messageExchange.setOperation(new QName("foo"));
    }

    @Test
 	public void testSetProperty() {
        messageExchange.setProperty("foo", new Object());
    }

    @Test
 	public void testSetService() {
        messageExchange.setService(new QName("foo"));
    }

    @Test
 	public void testSetStatus() throws MessagingException {
        messageExchange.setStatus(ExchangeStatus.ACTIVE);
    }

    @Test
 	public void testSetStatusThrowsMessagingException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

        Method method = getTestedClassMethod("setStatus", ExchangeStatus.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Override
    protected Class<?> getTestedApiClass() {
        return MessageExchange.class;
    }

}
