/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package javax.jbi.messaging;

import java.lang.reflect.Method;
import java.util.Set;

import javax.activation.DataHandler;
import javax.jbi.ApiChecker;
import javax.security.auth.Subject;
import javax.xml.transform.Source;

import org.junit.Test;
import org.mockito.Mockito;

/**
 * @author Olivier Fabre - EBM WebSourcing
 */
public class NormalizedMessageTest extends ApiChecker {

    NormalizedMessage mockNormalizedMessage = Mockito.mock(NormalizedMessage.class);

    @Test
    public void testAddAttachment() throws MessagingException {
        mockNormalizedMessage.addAttachment("foo", Mockito.mock(DataHandler.class));
    }

    @Test
    public void testAddAttachmentThrowsMessagingException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

        Method method = getTestedClassMethod("addAttachment", String.class, DataHandler.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testGetAttachment() {
        @SuppressWarnings("unused")
        DataHandler dataHandler = mockNormalizedMessage.getAttachment("foo");
    }

    @Test
    public void testGetAttachmentNames() {
        @SuppressWarnings({ "rawtypes", "unused" })
        Set set = mockNormalizedMessage.getAttachmentNames();
    }

    @Test
    public void testGetContent() {
        @SuppressWarnings("unused")
        Source source = mockNormalizedMessage.getContent();
    }

    @Test
    public void testGetProperty() {
        @SuppressWarnings("unused")
        Object object = mockNormalizedMessage.getProperty("foo");
    }

    @Test
    public void testGetPropertyNames() {
        @SuppressWarnings({ "rawtypes", "unused" })
        Set set = mockNormalizedMessage.getPropertyNames();
    }

    @Test
    public void testGetSecuritySubject() {
        @SuppressWarnings("unused")
        Subject subject = mockNormalizedMessage.getSecuritySubject();
    }

    @Test
    public void testRemoveAttachment() throws MessagingException {
        mockNormalizedMessage.removeAttachment("foo");
    }

    @Test
    public void testRemoveAttachmentThrowsMessagingException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

        Method method = getTestedClassMethod("removeAttachment", String.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testSetContent() throws MessagingException {
        mockNormalizedMessage.setContent(Mockito.mock(Source.class));
    }

    @Test
    public void testSetContentThrowsMessagingException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

        Method method = getTestedClassMethod("setContent", Source.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testSetProperty() {
        mockNormalizedMessage.setProperty("foo", new Object());
    }

    @Test
    public void testSetSecuritySubject() {
        mockNormalizedMessage.setSecuritySubject(new Subject());
    }

    @Override
    protected Class<?> getTestedApiClass() {
        return NormalizedMessage.class;
    }

}
